#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.cat_tps_interfaces.annotations import Annotations
from pycatia.system_interfaces.any_object import AnyObject


class TPSView(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     TPSView


    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tps_view = com_object

    @property
    def annotation_plane(self) -> tuple:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property AnnotationPlane() As CATSafeArrayVariant (Read Only)
                |     Reads view annotation plane.
                |
                |     Parameters:
                |
                |         oMathPlane
                |             Mathematical plane definition of the View.

        :rtype: tuple
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.tps_view.AnnotationPlane

    @property
    def annotation_sketch(self) -> AnyObject:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property AnnotationSketch(AnyObject Layout2DLView)
                |     Gets / Sets the annotation Sketch associated under the current
                |     View.
                |
                |     Parameters:
                |
                |         Layout2DLView
                |             2D Layout View used by current View as annotation sketch

        :rtype: AnyObject
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return AnyObject(self.tps_view.AnnotationSketch)

    @annotation_sketch.setter
    def annotation_sketch(self, value: AnyObject):
        """
        :param AnyObject value:
        """

        self.tps_view.AnnotationSketch = value

    @property
    def annotations(self) -> Annotations:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property Annotations() As Annotations (Read Only)
                |     Retrieves the TPS components of the View.
                |
                |     Parameters:
                |
                |         oAnnots
                |             Collection of returned component.

        :rtype: Annotations
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return Annotations(self.tps_view.Annotations)

    @property
    def display_ratio(self) -> int:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property DisplayRatio(double RatioValue)
                |     Sets / Gets the ratio of current View.
                |
                |     Parameters:
                |
                |         RatioValue
                |             Ratio applied to the View.

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.tps_view.DisplayRatio

    @display_ratio.setter
    def display_ratio(self, value: int):
        """
        :param False value:
        """

        self.tps_view.DisplayRatio = value

    @property
    def view_type(self) -> int:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property ViewType() As long (Read Only)
                |     Gets view type.
                |
                |     Parameters:
                |
                |         oViewType
                |             The view type
                |             Legal values:
                |
                |                 1: Front View
                |                 2: Section View
                |                 3: Cut View

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.tps_view.ViewType

    def __repr__(self):
        return f'TpsView(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingActivityToolPath(AnyObject):
    """

    Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingActivityToolPath
                |
                | Interface to compute the tool path of an activity.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_activity_tool_path = com_object

    def compute_and_set_tool_path(self) -> None:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Sub ComputeAndSetToolPath()
                |     Compute and set Tool Path for this operation

        :rtype: None
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.manufacturing_activity_tool_path.ComputeAndSetToolPath()

    def __repr__(self):
        return f'ManufacturingActivityToolPath(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R34 on 2026-03-08 14:35:32.197861

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
import inspect

from pycatia.manufacturing_interfaces.manufacturing_feature import ManufacturingFeature


class ManufacturingPattern2(ManufacturingFeature):
    """

    Introduced in V5-6R2024.

            .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-03-08 14:35:32.197861)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    ManufacturingInterfaces.ManufacturingFeature
                |                         ManufacturingPattern2
                | 
                | The Manufacturing Pattern is a specialized feature used to machine the same
                | item several times at several positions.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)

        self.release_check(
            self.application.system_configuration.release,
            34,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        self.com_object = com_object

    def set_pp_words_for_positions(self, i_point_number: int, i_list_pp_words: tuple) -> None:
        """

        Introduced in V5-6R2024.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-03-08 14:35:32.197861))
                | Sub SetPPWordsForPositions(short iPointNumber,CATSafeArrayVariant
                | ilistPPWords)
                |     Set all the PPWord lines of the record .
                | 
                |     Parameters:
                | 
                |         iPointNumber
                |             The number of the point 
                |         ilistPPWords
                |             The PPWords list of string 
                | 
                |     Example:
                |
                |          Dim Pattern
                |          Set Pattern = Operation.GetPattern()
                |          Dim textPPWord(2)
                |          textPPWord(0) = "PPWord1"
                |          textPPWord(1) = "PPWord2"
                |          Pattern.SetPPWordsForPositions 1, textPPWord

        :param int i_point_number:
        :param tuple i_list_pp_words:
        :rtype: None
        """
        return self.com_object.SetPPWordsForPositions(i_point_number, i_list_pp_words)

    def __repr__(self):
        return f'ManufacturingPattern2(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.drafting_interfaces.drawing_text_properties import DrawingTextProperties
from pycatia.system_interfaces.any_object import AnyObject


class DrawingCoordDim(AnyObject):
    """

    Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingCoordDim
                |
                | Represents a drawing Coordinate Dimension in a drawing view.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_coord_dim = com_object

    @property
    def angle(self) -> float:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property Angle() As double
                |     Returns or sets the angle of the drawing coordinate dimension. The angle is
                |     measured between the axis system of the drawing view and the local axis system
                |     of the drawing coordinate dimension. The angle is measured in radians and is
                |     counted counterclockwise.
                |
                |     Example:
                |         This example sets the angle of the MyCoordDim drawing Text to 90
                |         degrees clockwise. You first need to compute the angle in degrees and set the
                |         minus sign to indicate the rotation is clockwise.
                |
                |          Angle90Clockwise = -90
                |          MyCoordDim.Angle = Angle90Clockwise

        :rtype: float
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_coord_dim.Angle

    @angle.setter
    def angle(self, value: float):
        """
        :param float value:
        """

        self.drawing_coord_dim.Angle = value

    @property
    def text_properties(self) -> DrawingTextProperties:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property TextProperties() As DrawingTextProperties (Read Only)
                |     Returns the text properties of the drawing coordinate
                |     dimension.
                |
                |     Example:
                |         This example retrieves in TextProperties the text properties of the
                |         MyCoordDim drawing coordinate dimension..
                |
                |          Dim TextProperties As DrawingTextProperties
                |          Set TextProperties = MyCoordDim.TextProperties

        :rtype: DrawingTextProperties
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return DrawingTextProperties(self.drawing_coord_dim.TextProperties)

    @property
    def x(self) -> float:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property x() As double
                |     Returns or sets the x coordinate of the drawing coordinate dimension. It is
                |     expressed with respect to the current view coordinate system. This coordinate,
                |     like any length, is measured in millimeters.
                |
                |     Example:
                |         This example retrieves in X the x coordinate of the MyCoordDim drawing
                |         coordinate dimension.
                |
                |          X = MyCoordDim.x

        :rtype: float
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_coord_dim.x

    @x.setter
    def x(self, value: float):
        """
        :param float value:
        """

        self.drawing_coord_dim.x = value

    @property
    def y(self) -> float:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property y() As double
                |     Returns or sets the y coordinate of the drawing coordinate dimension. It is
                |     expressed with respect to the current view coordinate system. This coordinate,
                |     like any length, is measured in millimeters.
                |
                |     Example:
                |         This example sets the y coordinate of the MyCoordDim drawing coordinate
                |         dimension to 5 inches. You need first to convert the 5 inches into
                |         millmeters.
                |
                |          NewYCoordinate = 5*25.4/1000
                |          MyCoordDim.y = NewYCoordinate

        :rtype: float
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_coord_dim.y

    @y.setter
    def y(self, value: float):
        """
        :param float value:
        """

        self.drawing_coord_dim.y = value

    def get_coord_values(self, o_type: int, o_x: float, o_y: float, o_z: float) -> None:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Sub GetCoordValues(long oType,double oX,double oY,double oZ)
                |     Returns the value of the drawing coordinate dimension.
                |
                |     Parameters:
                |
                |         oType
                |             oType (0: 2D coordinate dimension, 1: 3D coordinate dimension).
                |
                |         oX
                |             X value.
                |         oY
                |             Y value.
                |         oZ
                |             Z value (=0. if 2D coordinate dimension).
                |
                |             Example:
                |                 This example gets the type, x, y and z of the MyCoordDim
                |                 drawing CoordDim
                |
                |                  MyCoordDim.GetCoordValues(oType, oX, oY, oZ)

        :param int o_type:
        :param float o_x:
        :param float o_y:
        :param float o_z:
        :rtype: None
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_coord_dim.GetCoordValues(o_type, o_x, o_y, o_z)

    def __repr__(self):
        return f'DrawingCoordDim(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2025-09-13 14:18:55.806894

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""

from pycatia.system_interfaces.any_object import AnyObject


class PageSetup(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PageSetup
                |
                | Represents the page setup.
                | The page setup is the object that stores data which defines how your documents
                | and images are actually printed on paper. This data includes namely the paper
                | size, the orientation, the bottom, top, right, and left margins, the zoom
                | factor, the banner, and the printing quality.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.page_setup = com_object

    @property
    def banner(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Banner() As CATBSTR
                |     Returns or sets the banner text. The banner text is added to the print and
                |     can include variables, such as the user who prints, the date and time of
                |     printing. Available variables are:
                |
                |     $USER
                |         The user name
                |     $HOST
                |         The workstation name
                |     $SCALE
                |         The print scale
                |     $TIME
                |         The print time
                |     $DATE
                |         The print date
                |     $DAY
                |         The print day
                |     $MONTH
                |         The print month
                |     $YEAR
                |         The print year
                |
                |     The default banner is:
                |
                |      Printed by $USER on $DATE $TIME
                |
                |
                |     Example:
                |         This example sets the banner text to the following:
                |         Printed by $USER at scale $SCALE on $MONTH/$DAY/$YEAR
                |         for the SetupForMyPrint page setup.
                |
                |          SetupForMyPrint.Banner = "Printed by $USER at scale $SCALE on $MONTH/$DAY/$YEAR"

        :return: str
        """

        return self.page_setup.Banner

    @banner.setter
    def banner(self, value: str):
        """
        :param str value:
        """

        self.page_setup.Banner = value

    @property
    def banner_position(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property BannerPosition() As CatBannerPosition
                |     Returns or sets the banner position. The banner can be located on the top,
                |     bottom, left, or right side of the page. catBannerPositionNone removes the
                |     banner.
                |
                |     Example:
                |         This example sets the banner on the top side of the page for the
                |         SetupForMyPrint page setup.
                |
                |          SetupForMyPrint.BannerPosition = CatBannerPositionTop

        :return: int
        """

        return self.page_setup.BannerPosition

    @banner_position.setter
    def banner_position(self, value: int):
        """
        :param int value:
        """

        self.page_setup.BannerPosition = value

    @property
    def banner_size(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property BannerSize() As float
                |     Returns or sets Banner Size. Banner size could range from 0.1 mm to 10.0 mm
                |     Default value is 2.4 mm
                |
                |     Example:
                |         This example sets banner size for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.BannerSize = 1.1

        :return: float
        """

        return self.page_setup.BannerSize

    @banner_size.setter
    def banner_size(self, value: float):
        """
        :param float value:
        """

        self.page_setup.BannerSize = value

    @property
    def bottom(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Bottom() As float
                |     Returns or sets the lower left corner location with respect to the bottom
                |     of the sheet of paper. This is the distance of the document or the image to
                |     print lower left corner to the paper lower left corner.
                |
                |     Example:
                |         This example sets the location of the lower left corner of the document
                |         or the image to print at 40 mm from the paper lower left corner for the
                |         SetupForMyPrint page setup.
                |
                |          SetupForMyPrint.Bottom = 40

        :return: float
        """

        return self.page_setup.Bottom

    @bottom.setter
    def bottom(self, value: float):
        """
        :param float value:
        """

        self.page_setup.Bottom = value

    @property
    def bottom_margin(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property BottomMargin() As float
                |     Returns or sets the bottom margin. The bottom margin is a strip in which
                |     nothing is printed, located at the bottom of the page, which height is
                |     expressed in mm.
                |
                |     Example:
                |         This example sets the bottom margin for the SetupForMyPrint page setup
                |         to 10 mm.
                |
                |          SetupForMyPrint.BottomMargin = 10

        :return: float
        """

        return self.page_setup.BottomMargin

    @bottom_margin.setter
    def bottom_margin(self, value: float):
        """
        :param float value:
        """

        self.page_setup.BottomMargin = value

    @property
    def color(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Color() As CatPrintColor
                |     Returns or sets the color mode to use when printing.
                |
                |     Example:
                |         This example sets the color mode to GreyScale for the SetupForMyPrint
                |         page setup.
                |
                |          SetupForMyPrint.Color = catColorGreyScale

        :return: int
        """

        return self.page_setup.Color

    @color.setter
    def color(self, value: int):
        """
        :param int value:
        """

        self.page_setup.Color = value

    @property
    def dpi(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Dpi() As float
                |     Returns or sets the printing dpi.
                |
                |     Example:
                |         This example sets the printing dpi for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.Dpi = 150.

        :return: float
        """

        return self.page_setup.Dpi

    @dpi.setter
    def dpi(self, value: float):
        """
        :param float value:
        """

        self.page_setup.Dpi = value

    @property
    def gamma(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Gamma() As float
                |     Returns or sets Gamma factor for print. Gamma value could range from 0.1 to
                |     5.0 Default value is 1.0
                |
                |     Example:
                |         This example sets Gamma factor for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.Gamma = 1.2

        :return: float
        """

        return self.page_setup.Gamma

    @gamma.setter
    def gamma(self, value: float):
        """
        :param float value:
        """

        self.page_setup.Gamma = value

    @property
    def left(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Left() As float
                |     Returns or sets the lower left corner location with respect to the left of
                |     the sheet of paper. This is the distance of the document or the image to print
                |     lower left corner to the paper lower left corner.
                |
                |     Example:
                |         This example sets the location of the lower left corner of the document
                |         or the image to print at 25 mm from the paper lower left corner for the
                |         SetupForMyPrint page setup.
                |
                |          SetupForMyPrint.Left = 25

        :return: float
        """

        return self.page_setup.Left

    @left.setter
    def left(self, value: float):
        """
        :param float value:
        """

        self.page_setup.Left = value

    @property
    def left_margin(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property LeftMargin() As float
                |     Returns or sets the left margin. The left margin is a strip in which
                |     nothing is printed, located at the left of the page, which width is expressed
                |     in mm.
                |
                |     Example:
                |         This example sets the left margin for the SetupForMyPrint page setup to
                |         10 mm.
                |
                |          SetupForMyPrint.LeftMargin = 10

        :return: float
        """

        return self.page_setup.LeftMargin

    @left_margin.setter
    def left_margin(self, value: float):
        """
        :param float value:
        """

        self.page_setup.LeftMargin = value

    @property
    def line_cap(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property LineCap() As CatPrintLineCap
                |     Returns or sets Line cap for print. Refer to CatPrintLineCap Default value
                |     is catPrintFlat
                |
                |     Example:
                |         This example sets Line cap for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.LineCap = catPrintFlat

        :return: int
        """

        return self.page_setup.LineCap

    @line_cap.setter
    def line_cap(self, value: int):
        """
        :param int value:
        """

        self.page_setup.LineCap = value

    @property
    def line_type_overlapping_check(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property LineTypeOverlappingCheck() As boolean
                |     Returns or sets text Line type overlap check option for print. Default
                |     value is FALSE
                |
                |     Example:
                |         This example sets Line type overlapping check option for the
                |         SetupForMyPrint page setup.
                |
                |          SetupForMyPrint.LineTypeOverlappingCheck = True

        :return: bool
        """

        return self.page_setup.LineTypeOverlappingCheck

    @line_type_overlapping_check.setter
    def line_type_overlapping_check(self, value: bool):
        """
        :param bool value:
        """

        self.page_setup.LineTypeOverlappingCheck = value

    @property
    def line_type_specification(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property LineTypeSpecification() As CatPrintLineSpecification
                |     Returns or sets Line type specification for print. Refer to
                |     CatPrintLineSpecification Default value is
                |     catPrintAbsolute
                |
                |     Example:
                |         This example sets Line type specification for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.LineTypeSpecification = catPrintAbsolute

        :return: int
        """

        return self.page_setup.LineTypeSpecification

    @line_type_specification.setter
    def line_type_specification(self, value: int):
        """
        :param int value:
        """

        self.page_setup.LineTypeSpecification = value

    @property
    def line_width_specification(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property LineWidthSpecification() As CatPrintLineSpecification
                |     Returns or sets Line width specification for print. Refer to
                |     CatPrintLineSpecification Default value is
                |     catPrintAbsolute
                |
                |     Example:
                |         This example sets Line width specification for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.LineWidthSpecification = catPrintAbsolute

        :return: int
        """

        return self.page_setup.LineWidthSpecification

    @line_width_specification.setter
    def line_width_specification(self, value: int):
        """
        :param int value:
        """

        self.page_setup.LineWidthSpecification = value

    @property
    def logo(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Logo() As CATBSTR
                |     Returns or sets the file containing the logo image. The logo is printed
                |     with the banner.
                |
                |     Example:
                |         This example sets the logo file to the following file:
                |         e:\\users\\psr\\Images\\Logo.tif for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.Logo = "e:\\users\\psr\\Images\\Logo.tif"

        :return: str
        """

        return self.page_setup.Logo

    @logo.setter
    def logo(self, value: str):
        """
        :param str value:
        """

        self.page_setup.Logo = value

    @property
    def logo_visibility(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property LogoVisibility() As boolean
                |     Returns or sets LogoVisibility option for print. Default value is
                |     FALSE
                |
                |     Example:
                |         This example sets LogoVisibility option for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.LogoVisibility = True

        :return: bool
        """

        return self.page_setup.LogoVisibility

    @logo_visibility.setter
    def logo_visibility(self, value: bool):
        """
        :param bool value:
        """

        self.page_setup.LogoVisibility = value

    @property
    def maximum_size(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property MaximumSize() As boolean
                |     Returns or sets whether the document or the image should be printed at the
                |     maximum size with respect to the page size and margins.
                |     True if the document or the image is printed with the maximum size. This
                |     overrides the location properties, that is Left and Bottom, and the Zoom
                |     property values.
                |
                |     Example:
                |         This example requests to print the document or the image with the
                |         SetupForMyPrint page setup at maximum size.
                |
                |          SetupForMyPrint.MaximumSize = True

        :return: bool
        """

        return self.page_setup.MaximumSize

    @maximum_size.setter
    def maximum_size(self, value: bool):
        """
        :param bool value:
        """

        self.page_setup.MaximumSize = value

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Orientation() As CatPaperOrientation
                |     Returns or sets the paper orientation.
                |
                |     Example:
                |         This example sets the paper orientation for the SetupForMyPrint page
                |         setup to catPaperLandscape.
                |
                |          SetupForMyPrint.Orientation = catPaperLandscape

        :return: int
        """

        return self.page_setup.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.page_setup.Orientation = value

    @property
    def paper_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property PaperHeight() As float
                |     Returns or sets the paper height.
                |
                |     Example:
                |         This example sets the page height for the SetupForMyPrint page setup to
                |         297 mm..
                |
                |          SetupForMyPrint.PaperHeight = 297

        :return: float
        """

        return self.page_setup.PaperHeight

    @paper_height.setter
    def paper_height(self, value: float):
        """
        :param float value:
        """

        self.page_setup.PaperHeight = value

    @property
    def paper_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property PaperSize() As CatPaperSize
                |     Returns or sets the paper size.
                |
                |     Example:
                |         This example sets the page size for the SetupForMyPrint page setup to
                |         catPaperA4.
                |
                |          SetupForMyPrint.PaperSize = catPaperA4

        :return: int
        """

        return self.page_setup.PaperSize

    @paper_size.setter
    def paper_size(self, value: int):
        """
        :param int value:
        """

        self.page_setup.PaperSize = value

    @property
    def paper_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property PaperWidth() As float
                |     Returns or sets the paper width.
                |
                |     Example:
                |         This example sets the page width for the SetupForMyPrint page setup to
                |         210 mm..
                |
                |          SetupForMyPrint.PaperWidth = 210

        :return: float
        """

        return self.page_setup.PaperWidth

    @paper_width.setter
    def paper_width(self, value: float):
        """
        :param float value:
        """

        self.page_setup.PaperWidth = value

    @property
    def print_rendering_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property PrintRenderingMode() As CatPrintRenderingMode
                |     Returns or sets the printing rendering mode.
                |
                |     Example:
                |         This example sets the printing rendering mode for the SetupForMyPrint
                |         page setup.
                |
                |          SetupForMyPrint.PrintRenderingMode = CatPrintRenderingModeDefault

        :return: int
        """

        return self.page_setup.PrintRenderingMode

    @print_rendering_mode.setter
    def print_rendering_mode(self, value: int):
        """
        :param int value:
        """

        self.page_setup.PrintRenderingMode = value

    @property
    def quality(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Quality() As CatPrintQuality
                |     Returns or sets the printing quality. Refer to
                |     CatPrintQuality
                |
                |     Example:
                |         This example sets the printing quality to draft for the SetupForMyPrint
                |         page setup.
                |
                |          SetupForMyPrint.Quality = catPrintQualityDraft

        :return: int
        """

        return self.page_setup.Quality

    @quality.setter
    def quality(self, value: int):
        """
        :param int value:
        """

        self.page_setup.Quality = value

    @property
    def right_margin(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property RightMargin() As float
                |     Returns or sets the right margin. The right margin is a strip in which
                |     nothing is printed, located at the right of the page, which width is expressed
                |     in mm.
                |
                |     Example:
                |         This example sets the right margin for the SetupForMyPrint page setup
                |         to 12 mm.
                |
                |          SetupForMyPrint.RightMargin = 12

        :return: float
        """

        return self.page_setup.RightMargin

    @right_margin.setter
    def right_margin(self, value: float):
        """
        :param float value:
        """

        self.page_setup.RightMargin = value

    @property
    def rotation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Rotation() As CatImageRotation
                |     Returns or sets the rotation of the document or the image to print.
                |     Rotations angles can be 0, 90, 180, and 270 degrees counted
                |     clockwise.
                |
                |     Example:
                |         This example sets the rotation to 90 degrees clockwise for the
                |         SetupForMyPrint page setup.
                |
                |          SetupForMyPrint.Rotation = catImageRotation90

        :return: int
        """

        return self.page_setup.Rotation

    @rotation.setter
    def rotation(self, value: int):
        """
        :param int value:
        """

        self.page_setup.Rotation = value

    @property
    def scaling1_to1(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Scaling1To1() As boolean
                |     Returns or sets whether the document or the image should be printed with a
                |     zoom factor equals to 1 and the image to print lower left corner on the paper
                |     lower corner.
                |     True if the document or the image is printed with the zoom factor equals to
                |     1 and the image to print lower left corner on the paper lower corner. This
                |     overrides the location properties, that is Left and Bottom, and the Zoom
                |     property values.
                |
                |     Example:
                |         This example requests to print the document or the image with the
                |         SetupForMyPrint page setup.
                |
                |          SetupForMyPrint.Scaling1To1 = True

        :return: bool
        """

        return self.page_setup.Scaling1To1

    @scaling1_to1.setter
    def scaling1_to1(self, value: bool):
        """
        :param bool value:
        """

        self.page_setup.Scaling1To1 = value

    @property
    def text_blanking(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property TextBlanking() As boolean
                |     Returns or sets the text blanking option in print Text will be printed in
                |     blanking rectangle Default value is FALSE
                |
                |     Example:
                |         This example sets the text blanking option for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.TextBlanking = True

        :return: bool
        """

        return self.page_setup.TextBlanking

    @text_blanking.setter
    def text_blanking(self, value: bool):
        """
        :param bool value:
        """

        self.page_setup.TextBlanking = value

    @property
    def text_scaling(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property TextScaling() As boolean
                |     Returns or sets text scaling option for print. Default value is
                |     TRUE
                |
                |     Example:
                |         This example sets text scaling option for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.TextScaling = True

        :return: bool
        """

        return self.page_setup.TextScaling

    @text_scaling.setter
    def text_scaling(self, value: bool):
        """
        :param bool value:
        """

        self.page_setup.TextScaling = value

    @property
    def top_margin(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property TopMargin() As float
                |     Returns or sets the top margin. The top margin is a strip in which nothing
                |     is printed, located at the top of the page, which height is expressed in
                |     mm.
                |
                |     Example:
                |         This example sets the top margin for the SetupForMyPrint page setup to
                |         15 mm.
                |
                |          SetupForMyPrint.TopMargin = 15

        :return: float
        """

        return self.page_setup.TopMargin

    @top_margin.setter
    def top_margin(self, value: float):
        """
        :param float value:
        """

        self.page_setup.TopMargin = value

    @property
    def use3_d_accuracy(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Use3DAccuracy() As boolean
                |     Returns or sets Use3DAccuracy option for print. Default value is
                |     FALSE
                |
                |     Example:
                |         This example sets Use3DAccuracy option for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.Use3DAccuracy = True

        :return: bool
        """

        return self.page_setup.Use3DAccuracy

    @use3_d_accuracy.setter
    def use3_d_accuracy(self, value: bool):
        """
        :param bool value:
        """

        self.page_setup.Use3DAccuracy = value

    @property
    def use_image_size(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property UseImageSize() As boolean
                |     Returns or sets the paper size to the image size.
                |
                |     Example:
                |         This example sets the paper size to image size for the SetupForMyPrint
                |         page setup.
                |
                |          SetupForMyPrint.UseImageSize = True

        :return: bool
        """

        return self.page_setup.UseImageSize

    @use_image_size.setter
    def use_image_size(self, value: bool):
        """
        :param bool value:
        """

        self.page_setup.UseImageSize = value

    @property
    def white_vectors_in_black(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property WhiteVectorsInBlack() As boolean
                |     Returns or sets the white vectors in black option. white vectors will be
                |     printed in black if set to True Default value is TRUE
                |
                |     Example:
                |         This example sets the Print White Vectors In Black option for the
                |         SetupForMyPrint page setup.
                |
                |          SetupForMyPrint.WhiteVectorsInBlack = True

        :return: bool
        """

        return self.page_setup.WhiteVectorsInBlack

    @white_vectors_in_black.setter
    def white_vectors_in_black(self, value: bool):
        """
        :param bool value:
        """

        self.page_setup.WhiteVectorsInBlack = value

    @property
    def zoom(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2025-09-13 14:18:55.806894)
                | Property Zoom() As float
                |     Returns or sets the zoom factor to use when printing.
                |
                |     Example:
                |         This example sets the zoom factor to 1.5 for the SetupForMyPrint page
                |         setup.
                |
                |          SetupForMyPrint.Zoom = 1.5

        :return: float
        """

        return self.page_setup.Zoom

    @zoom.setter
    def zoom(self, value: float):
        """
        :param float value:
        """

        self.page_setup.Zoom = value

    def __repr__(self):
        return f'PageSetup(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.manufacturing_interfaces.manufacturing_operation import ManufacturingOperation
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingProgram2(AnyObject):
    """

    Introduced in V5-6R2020.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingProgram2
                |
                | A ManufacturingProgram for a Manufacturing Document.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_program2 = com_object

    def append_operation_after(
            self,
            i_manufacturing_operation: ManufacturingOperation,
            type_: str,
            auto_sequence: int) -> ManufacturingOperation:
        """

        Introduced in V5-6R2020.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func AppendOperationAfter(ManufacturingOperation
                | iManufacturingOperation,CATBSTR type,short AutoSequence) As
                | ManufacturingOperation
                |     Create and Insert a Manufacturing Operation of a specified type after the
                |     existing operation.
                |     if AutoSequence is set to 1, the new operation will be sequenced in the
                |     Program.
                |
                |     Example:
                |         The following example creates, inserts and sequences
                |         in firstProgram the manufacturing operation ManufacturingOperation
                |         of type : type
                |
                |         Set ManufacturingOperation = firstProgram.AppendOperationAfter(operation,Type,1)

        :param ManufacturingOperation i_manufacturing_operation:
        :param str type_:
        :param int auto_sequence:
        :rtype: ManufacturingOperation
        """

        self.release_check(
            self.application.system_configuration.release,
            30,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return ManufacturingOperation(
            self.manufacturing_program2.AppendOperationAfter(
                i_manufacturing_operation.com_object,
                type_,
                auto_sequence
            )
        )

    def append_operation_before(
            self,
            i_manufacturing_operation: ManufacturingOperation,
            type_: str,
            auto_sequence: int
    ) -> ManufacturingOperation:
        """

        Introduced in V5-6R2020.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func AppendOperationBefore(ManufacturingOperation
                | iManufacturingOperation,CATBSTR type,short AutoSequence) As
                | ManufacturingOperation
                |     Create and Insert a Manufacturing Operation of a specified type before the
                |     existing operation.
                |     if AutoSequence is set to 1, the new operation will be sequenced in the
                |     Program.
                |
                |     Example:
                |         The following example creates, inserts and sequences
                |         in firstProgram the manufacturing operation ManufacturingOperation
                |         of type : type
                |
                |          Set ManufacturingOperation = firstProgram.AppendOperationBefore(operation,Type,1)

        :param ManufacturingOperation i_manufacturing_operation:
        :param str type_:
        :param int auto_sequence:
        :rtype: ManufacturingOperation
        """

        self.release_check(
            self.application.system_configuration.release,
            30,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return ManufacturingOperation(
            self.manufacturing_program2.AppendOperationBefore(
                i_manufacturing_operation.com_object,
                type_,
                auto_sequence
            )
        )

    def __repr__(self):
        return f'ManufacturingProgram2(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2026-02-21 14:49:57.443389

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
import inspect

from pycatia.system_interfaces.any_object import AnyObject


class AnnotationSetTmpNoaIsolating(AnyObject):
    """

        Introduced in V5-6R2022.


        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-02-21 14:49:57.443389)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnnotationSetTmpNOAIsolating
                | 
                | Interface for the Technological Product Specification (TPS)
                | objects.
                | Leaf entity in the Design Pattern Composite. TPS modeler enables definition of
                | specification related to surfaces. Temporary interface retrieved using
                | "GetItem" call onto AnnotationSet object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )
        self.com_object = com_object

    def isolate_links_of_noa(self) -> None:
        """

        Introduced in V5-6R2022.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-02-21 14:49:57.443389))
                | Sub IsolateLinksOfNOA()
                |     Method responsible to remove all the links in between ditto NOA and the 2D
                |     instantiated Detail. This call focuses the remaining link in between the ditto
                |     NOA and the 2D Drafting component used for its representation. The handling is
                |     global to the authored content and results in isolating all the existing ditto
                |     NOAs.

        :rtype: None
        """
        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )
        return self.com_object.IsolateLinksOfNOA()

    def __repr__(self):
        return f'AnnotationSetTmpNoaIsolating(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.drafting_interfaces.drawing_gdt import DrawingGDT
from pycatia.system_interfaces.collection import Collection


class DrawingGDTs(Collection):
    """

    Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DrawingGDTs
                |
                | A collection of all the drawing GDTs currently managed by a drawing view of
                | drawing sheet in a drawing document.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_gd_ts = com_object

    def add(
            self,
            i_position_leader_x: float,
            i_position_leader_y: float,
            i_position_x: float,
            i_position_y: float,
            i_gdt_symbol: int,
            i_text: str
    ) -> DrawingGDT:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func Add(double iPositionLeaderX,double iPositionLeaderY,double
                | iPositionX,double iPositionY,long iGDTSymbol,CATBSTR iText) As
                | DrawingGDT
                |     Creates a drawing GDT and adds it to the drawing GDTs collection. This
                |     drawing GDT becomes the active one.
                |
                |     Parameters:
                |
                |         iPositionLeaderX,
                |             iPositionLeaderY The drawing leader of the GDT x and y coordinates,
                |             expressed in millimeters, and expressed with respect to the view coordinate
                |             system
                |         iPositionX,
                |             iPositionY The drawing GDT x and y coordinates, expressed in
                |             millimeters, and expressed with respect to the view coordinate system
                |
                |         iGDTSymbol
                |             The symbol to use in the first row.
                |
                |     See also:
                |         CATIADrawingGDT::GetToleranceType
                |     Parameters:
                |
                |         iText
                |             The text of the iGDTSymbol

        :param float i_position_leader_x:
        :param float i_position_leader_y:
        :param float i_position_x:
        :param float i_position_y:
        :param int i_gdt_symbol:
        :param str i_text:
        :rtype: DrawingGDT
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return DrawingGDT(
            self.drawing_gd_ts.Add(
                i_position_leader_x,
                i_position_leader_y,
                i_position_x,
                i_position_y,
                i_gdt_symbol,
                i_text
            )
        )

    def item(self, i_index: int) -> DrawingGDT:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func Item(long iIndex) As DrawingGDT
                |     Returns a drawing GDT using its index from the drawing GDTs
                |     collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the drawing GDT to retrieve from the collection of
                |             drawing GDTs. As a numerics, this index is the rank of the drawing GDT in the
                |             collection. The index of the first drawing GDT in the collection is 1, and the
                |             index of the last drawing GDT is Count.
                |
                |     Returns:
                |         The retrieved drawing GDT
                |
                | Example:
                |     This example retrieves in ThisDrawingGDT the second drawing GDT, in the
                |     drawing GDT collection of the active view in the active sheet, in the active
                |     document supposed to be a drawing document.
                |
                |      Dim MyView  As DrawingView
                |      Set MyView  = MySheet.Views.ActiveView
                |      Dim ThisDrawingGDT As DrawingGDT
                |      Set ThisDrawingGDT = MyView.GDTs.Item(2)

        :param int i_index:
        :rtype: DrawingGDT
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return DrawingGDT(self.drawing_gd_ts.Item(i_index))

    def remove(self, i_index: int) -> None:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Sub Remove(long iIndex)
                |     Removes a drawing GDT from the drawing GDTs collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the drawing GDT to remove from the collection of
                |             drawing GDTs. As a numerics, this index is the rank of the drawing text in the
                |             collection. The index of the first drawing GDT in the collection is 1, and the
                |             index of the last drawing GDT is Count.
                |
                |     Example:
                |         The following example removes the third drawing GDT from the drawing
                |         GDT collection of the active view of the active document, supposed to be a
                |         drawing document.
                |
                |          Dim MyView As DrawingView
                |          Set MyView  = MySheet.Views.ActiveView
                |          MyView.GDTs.Remove(3)

        :param int i_index:
        :rtype: None
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_gd_ts.Remove(i_index)

    def __repr__(self):
        return f'DrawingGDTs(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.system_interfaces.any_object import AnyObject


class NumericalDisplayFormat(AnyObject):
    """

    Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     NumericalDisplayFormat
                |
                | Interface to manage numerical format properties of GST, DRF and Datum
                | Target.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.numerical_display_format = com_object

    @property
    def available_display_factor(self) -> int:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property AvilableDisplayFactor() As long (Read Only)
                |     Retrieves or sets the maximun level of factor available to be
                |     displayed.
                |     It may vary according to the name of the format.

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.numerical_display_format.AvilableDisplayFactor

    @property
    def display_factor(self) -> int:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property DisplayFactor() As long
                |     Retrieves or sets the level of factor to be displayed.
                |     The numerical values associated to the annotation will be displayed as per
                |     this Display Factor.

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.numerical_display_format.DisplayFactor

    @display_factor.setter
    def display_factor(self, value: int):
        """
        :param int value:
        """

        self.numerical_display_format.DisplayFactor = value

    @property
    def display_leading_zero(self) -> int:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property DisplayLeadingZero() As long
                |     Retrieves or sets the annotation DisplayLeadingZero.
                |     The numerical values associated to the annotation will be displayed as per
                |     this DisplayLeadingZero.
                |     The integer value of onValue/inValue corresponding to:
                |     0 : no display of LeadingZero.
                |     1 : display the LeadingZero.

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.numerical_display_format.DisplayLeadingZero

    @display_leading_zero.setter
    def display_leading_zero(self, value: int):
        """
        :param int value:
        """

        self.numerical_display_format.DisplayLeadingZero = value

    @property
    def display_trailing_zero(self) -> int:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property DisplayTrailingZero() As long
                |     Retrieves or sets the annotation DisplayTrailingZero.
                |     The numerical values associated to the annotation will be displayed as per
                |     this DisplayTrailingZero.
                |     The integer value of onValue/inValue corresponding to:
                |     0 : no display of TrailingZero.
                |     1 : display the TrailingZero.

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.numerical_display_format.DisplayTrailingZero

    @display_trailing_zero.setter
    def display_trailing_zero(self, value: int):
        """
        :param int value:
        """

        self.numerical_display_format.DisplayTrailingZero = value

    @property
    def format_name(self) -> str:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property FormatName() As CATBSTR
                |     Retrieves or sets the format name.
                |     The numerical values associated to the annotation will be displayed as per
                |     this format.

        :rtype: str
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.numerical_display_format.FormatName

    @format_name.setter
    def format_name(self, value: str):
        """
        :param str value:
        """

        self.numerical_display_format.FormatName = value

    @property
    def precision(self) -> int:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property Precision() As long
                |     Retrieves or sets the precision of annotation.
                |     The numerical values associated to the annotation will be displayed as per
                |     this precision.

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.numerical_display_format.Precision

    @precision.setter
    def precision(self, value: int):
        """
        :param int value:
        """

        self.numerical_display_format.Precision = value

    @property
    def separator(self) -> int:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property Separator() As long
                |     Retrieves or sets the annotation separator.
                |     The numerical values associated to the annotation will be displayed with
                |     this seperator.
                |     The integer value of onValue/inValue corresponding to:
                |     0 ""
                |     1 "/"
                |     2 ":"
                |     3 "("
                |     4 ")"
                |     5 "\\"
                |     6 ","
                |     7 "<"
                |     8 ">"
                |     9 "X"
                |     10 "*"
                |     11 "."
                |     12 ";"
                |     13 "+"
                |     14 "["
                |     15 "]"
                |     16 "-"
                |     17 "_"
                |     18 " "

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.numerical_display_format.Separator

    @separator.setter
    def separator(self, value: int):
        """
        :param int value:
        """

        self.numerical_display_format.Separator = value

    def __repr__(self):
        return f'NumericalDisplayFormat(name="{self.name}")'



from typing import Union

from pycatia.knowledge_interfaces.bool_param import BoolParam
from pycatia.knowledge_interfaces.free_parameter import FreeParameter
from pycatia.knowledge_interfaces.int_param import IntParam
from pycatia.knowledge_interfaces.list_parameter import ListParameter
from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.knowledge_interfaces.str_param import StrParam
from pycatia.knowledge_interfaces.real_param import RealParam

AnyParameter = Union[
    BoolParam,
    FreeParameter,
    IntParam,
    ListParameter,
    Parameter,
    RealParam,
    StrParam,
]
